@@ -1,6 +1,6 @@
 #' Framework7 panel
 #'
-#' \link{f7Panel} is a sidebar element. It may be used as a simple
+#' \code{f7Panel} is a sidebar element. It may be used as a simple
 #' sidebar or as a container for \link{f7PanelMenu} in case of
 #' \link{f7SplitLayout}.
 #'
@@ -134,7 +134,7 @@ f7Panel <- function(..., id = NULL, title = NULL,
 
 #' Framework7 sidebar menu
 #'
-#' \link{f7PanelMenu} creates a menu for \link{f7Panel}. It may contain
+#' \code{f7PanelMenu} creates a menu for \link{f7Panel}. It may contain
 #' multiple \link{f7PanelItem}.
 #'
 #' @param ... Slot for \link{f7PanelItem}.
@@ -159,7 +159,7 @@ f7PanelMenu <- function(..., id = NULL) {
         // If no tab is active at start, the first tab is shown by default.
         $(function() {
           var firstPanel = $('#", id," li:eq(0)');
-          var panelActiveId = $('#", id," a.tab-link-active').attr('href');
+          var panelActiveId = $('#", id," a.tab-link-active').attr('data-tab');
           if (panelActiveId != undefined) {
             app.tab.show(panelActiveId);
           } else {
@@ -184,7 +184,7 @@ f7PanelMenu <- function(..., id = NULL) {
 
           // update the input value
           $(window).on('click', function(e) {
-           var selectedPanelVal = $('#", id," a.tab-link-active').attr('href');
+           var selectedPanelVal = $('#", id," a.tab-link-active').attr('data-tab');
            var selectedPanelVal = selectedPanelVal.split('#')[1];
            Shiny.setInputValue('", id, "', selectedPanelVal);
           });
@@ -208,7 +208,7 @@ f7PanelMenu <- function(..., id = NULL) {
 
 #' Framework7 sidebar menu item
 #'
-#' \link{f7PanelItem} creates a Framework7 sidebar menu item for \link{f7SplitLayout}.
+#' \code{f7PanelItem} creates a Framework7 sidebar menu item for \link{f7SplitLayout}.
 #'
 #' @param title Item name.
 #' @param tabName Item unique tabName. Must correspond to what is passed to
@@ -224,14 +224,14 @@ f7PanelItem <- function(title, tabName, icon = NULL, active = FALSE) {
     # generate the link
     if (!is.null(icon)) {
       shiny::a(
-        href = paste0("#", tabName),
+        `data-tab`= paste0("#", tabName),
         class = if (active) "tab-link tab-link-active" else "tab-link",
         icon,
         shiny::span(class = "tabbar-label", title)
       )
     } else {
       shiny::a(
-        href = paste0("#", tabName),
+        `data-tab` = paste0("#", tabName),
         class = if (active) "tab-link tab-link-active" else "tab-link",
         title
       )
@@ -245,7 +245,7 @@ f7PanelItem <- function(title, tabName, icon = NULL, active = FALSE) {
 
 #' Update Framework7 panel
 #'
-#' \link{updateF7Panel} toggles a \link{f7Panel} from the server.
+#' \code{updateF7Panel} toggles an \link{f7Panel} from the server.
 #'
 #' @param id Panel unique id.
 #' @param session Shiny session object.
