@@ -4,14 +4,56 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ----setup--------------------------------------------------------------------
-library(shiny)
-library(shinyMobile)
-
 ## ---- eval = FALSE------------------------------------------------------------
+#  library(shiny)
+#  library(shinyMobile)
 #  preview_mobile(appPath = system.file("examples/gallery/app.R", package = "shinyMobile"), device = "iphoneX")
 #  preview_mobile(url = "https://dgranjon.shinyapps.io/miniUI2DemoMd", device = "ipadMini")
 
+## ---- eval=FALSE--------------------------------------------------------------
+#  shinyApp(
+#    ui = f7Page(
+#      title = "My app",
+#      options = list(pullToRefresh = TRUE),
+#      f7SingleLayout(
+#        navbar = f7Navbar(
+#          title = "Single Layout",
+#          hairline = FALSE,
+#          shadow = TRUE
+#        ),
+#        toolbar = f7Toolbar(
+#          position = "bottom",
+#          f7Link(label = "Link 1", href = "https://www.google.com"),
+#          f7Link(label = "Link 2", href = "https://www.google.com")
+#        ),
+#        # main content
+#        f7List(
+#          lapply(1:3, function(j) {
+#            f7ListItem(
+#              letters[j],
+#              media = f7Icon("alarm_fill"),
+#              right = "Right Text",
+#              header = "Header",
+#              footer = "Footer"
+#            )
+#          })
+#        )
+#      )
+#    ),
+#    server = function(input, output, session) {
+#      observe(print(input$ptr))
+#  
+#      observeEvent(input$ptr, {
+#        ptrStatus <- if (input$ptr) "on"
+#        f7Dialog(
+#          text = paste('ptr is', ptrStatus),
+#          type = "alert"
+#        )
+#      })
+#    }
+#  )
+#  
+
 ## ---- eval = FALSE------------------------------------------------------------
 #  shiny::shinyApp(
 #    ui = f7Page(
@@ -34,7 +76,7 @@ library(shinyMobile)
 #  )
 
 ## ---- eval = FALSE------------------------------------------------------------
-#  shiny::shinyApp(
+#  shinyApp(
 #    ui = f7Page(
 #      title = "My app",
 #      f7SingleLayout(
@@ -52,7 +94,7 @@ library(shinyMobile)
 #  
 #      output$userAgent <- renderText(input$deviceInfo$desktop)
 #  
-#      # generate a card inkly for desktop
+#      # generate a card only for desktop
 #      output$card <- renderUI({
 #        if (input$deviceInfo$desktop) {
 #          f7Card(
@@ -66,9 +108,7 @@ library(shinyMobile)
 #  )
 
 ## ---- eval = FALSE------------------------------------------------------------
-#  library(shiny)
-#  library(shinyMobile)
-#  shiny::shinyApp(
+#  shinyApp(
 #    ui = f7Page(
 #      title = "My app",
 #      f7SingleLayout(
@@ -79,8 +119,8 @@ library(shinyMobile)
 #        ),
 #        toolbar = f7Toolbar(
 #          position = "bottom",
-#          f7Link(label = "Link 1", src = "https://www.google.com"),
-#          f7Link(label = "Link 2", src = "https://www.google.com", external = TRUE)
+#          f7Link(label = "Link 1", href = "https://www.google.com"),
+#          f7Link(label = "Link 2", href = "https://www.google.com")
 #        ),
 #        # main content
 #        f7Card(verbatimTextOutput("infos")),
