@@ -36,7 +36,7 @@ tabBtns <- f7Tab(
   f7Segment(
     container = "row",
     f7Button(color = "blue", label = "My button", fill = FALSE),
-    f7Button(color = "green", label = "My button", src = "http://www.google.com", fill = FALSE),
+    f7Button(color = "green", label = "My button", href = "http://www.google.com", fill = FALSE),
     f7Button(color = "yellow", label = "My button", fill = FALSE)
   ),
   f7BlockTitle(title = "Filled Buttons in a segment/rounded container"),
@@ -44,7 +44,7 @@ tabBtns <- f7Tab(
     rounded = TRUE,
     container = "segment",
     f7Button(color = "black", label = "Action Button", inputId = "button2"),
-    f7Button(color = "green", label = "My button", src = "http://www.google.com"),
+    f7Button(color = "green", label = "My button", href = "http://www.google.com"),
     f7Button(color = "yellow", label = "My button")
   ),
   f7BlockTitle(title = "Outline Buttons in a segment/shadow container"),
@@ -72,5 +72,19 @@ tabBtns <- f7Tab(
 
   br(), br(),
   f7BlockTitle(title = "Click on the black action button to update the value"),
-  textOutput("val")
+  textOutput("val"),
+  br(), br(),
+
+  # Menus
+  f7Button("toggleMenu", "Toggle menu"),
+  f7Menu(
+    f7MenuDropdown(
+      id = "menu1",
+      label = "Menu 1",
+      f7MenuItem(inputId = "menuItem1", "Item 1"),
+      f7MenuItem(inputId = "menuItem2", "Item 2"),
+      f7MenuDropdownDivider(),
+      f7MenuItem(inputId = "menuItem3", "Item 3")
+    )
+  )
 )
